@@ -14,12 +14,13 @@ const PWD: &str = "/tmp/xplr_bench";
 fn navigation_benchmark(c: &mut Criterion) {
     fs::create_dir_all(PWD).unwrap();
     (1..10000).for_each(|i| {
-        fs::File::create(std::path::Path::new(PWD).join(i.to_string())).unwrap();
+        fs::File::create(std::path::Path::new(PWD).join(i.to_string()))
+            .unwrap();
     });
 
     let lua = mlua::Lua::new();
-    let mut app =
-        app::App::create(PWD.into(), &lua, None, [].into()).expect("failed to create app");
+    let mut app = app::App::create(PWD.into(), &lua, None, [].into())
+        .expect("failed to create app");
 
     app = app
         .clone()
@@ -93,12 +94,13 @@ fn navigation_benchmark(c: &mut Criterion) {
 fn draw_benchmark(c: &mut Criterion) {
     fs::create_dir_all(PWD).unwrap();
     (1..10000).for_each(|i| {
-        fs::File::create(std::path::Path::new(PWD).join(i.to_string())).unwrap();
+        fs::File::create(std::path::Path::new(PWD).join(i.to_string()))
+            .unwrap();
     });
 
     let lua = mlua::Lua::new();
-    let mut app =
-        app::App::create(PWD.into(), &lua, None, [].into()).expect("failed to create app");
+    let mut app = app::App::create(PWD.into(), &lua, None, [].into())
+        .expect("failed to create app");
 
     app = app
         .clone()
