@@ -1,6 +1,7 @@
 use crossterm::event::{KeyCode, KeyEvent, KeyModifiers};
 use serde::{Deserialize, Serialize};
 use std::cmp::Ordering;
+use tui_input::InputRequest;
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq, Hash, Serialize, Deserialize)]
 #[serde(rename_all = "kebab-case")]
@@ -111,6 +112,23 @@ pub enum Key {
     CtrlY,
     CtrlZ,
 
+    CtrlBackspace,
+    CtrlLeft,
+    CtrlRight,
+    CtrlUp,
+    CtrlDown,
+    CtrlHome,
+    CtrlEnd,
+    CtrlPageUp,
+    CtrlPageDown,
+    CtrlBackTab,
+    CtrlDelete,
+    CtrlInsert,
+    CtrlEnter,
+    CtrlSpace,
+    CtrlTab,
+    CtrlEsc,
+
     AltA,
     AltB,
     AltC,
@@ -179,7 +197,7 @@ impl std::fmt::Display for Key {
                 _ => c.to_string(),
             })
             .unwrap_or_else(|| {
-                serde_yaml::to_value(self)
+                serde_yaml::to_value(&self)
                     .ok()
                     .and_then(|v| v.as_str().map(|v| v.to_string()))
                     .unwrap_or_default()
@@ -190,6 +208,28 @@ impl std::fmt::Display for Key {
 }
 
 impl Key {
+    pub fn to_input_operation(&self) -> Option<InputOperation> {
+        use InputOperation::*;
+        use Key::*;
+
+        match self {
+            Backspace => Some(DeletePreviousCharacter),
+            Delete => Some(DeleteNextCharacter),
+            Tab => Some(InsertCharacter('\t')),
+            Space => Some(InsertCharacter(' ')),
+            Left => Some(GoToPreviousCharacter),
+            CtrlLeft => Some(GoToPreviousWord),
+            Right => Some(GoToNextCharacter),
+            CtrlRight => Some(GoToNextWord),
+            CtrlU => Some(DeleteLine),
+            CtrlW => Some(DeletePreviousWord),
+            CtrlDelete => Some(DeleteNextWord),
+            CtrlA => Some(GoToStart),
+            CtrlE => Some(GoToEnd),
+            key => key.to_char().map(InsertCharacter),
+        }
+    }
+
     pub fn from_event(key: KeyEvent) -> Self {
         match key.modifiers {
             KeyModifiers::CONTROL => match key.code {
@@ -219,6 +259,23 @@ impl Key {
                 KeyCode::Char('x') => Key::CtrlX,
                 KeyCode::Char('y') => Key::CtrlY,
                 KeyCode::Char('z') => Key::CtrlZ,
+                KeyCode::Char(' ') => Key::CtrlSpace,
+
+                KeyCode::Backspace => Key::CtrlBackspace,
+                KeyCode::Left => Key::CtrlLeft,
+                KeyCode::Right => Key::CtrlRight,
+                KeyCode::Up => Key::CtrlUp,
+                KeyCode::Down => Key::CtrlDown,
+                KeyCode::Home => Key::CtrlHome,
+                KeyCode::End => Key::CtrlEnd,
+                KeyCode::PageUp => Key::CtrlPageUp,
+                KeyCode::PageDown => Key::CtrlPageDown,
+                KeyCode::BackTab => Key::CtrlBackTab,
+                KeyCode::Delete => Key::CtrlDelete,
+                KeyCode::Insert => Key::CtrlInsert,
+                KeyCode::Enter => Key::CtrlEnter,
+                KeyCode::Tab => Key::CtrlTab,
+                KeyCode::Esc => Key::CtrlEsc,
 
                 KeyCode::Char(c) => c.into(),
 
@@ -380,11 +437,124 @@ impl Key {
         )
     }
 
-    pub fn is_special_character(&self) -> bool {
-        matches!(self, Self::Special(_))
+    pub fn is_alphanumeric(&self) -> bool {
+        self.is_alphabet() || self.is_number()
     }
 
-    pub fn to_char(self) -> Option<char> {
+    pub fn is_special_character(&self) -> bool {
+        matches!(&self, Self::Special(_))
+    }
+
+    pub fn is_character(&self) -> bool {
+        self.is_alphanumeric() || self.is_special_character()
+    }
+
+    pub fn is_function(&self) -> bool {
+        matches!(
+            self,
+            Self::F1
+                | Self::F2
+                | Self::F3
+                | Self::F4
+                | Self::F5
+                | Self::F6
+                | Self::F7
+                | Self::F8
+                | Self::F9
+                | Self::F10
+                | Self::F11
+                | Self::F12
+        )
+    }
+
+    pub fn is_navigation(&self) -> bool {
+        matches!(
+            self,
+            Self::Backspace
+                | Self::Left
+                | Self::Right
+                | Self::Up
+                | Self::Down
+                | Self::Home
+                | Self::End
+                | Self::PageUp
+                | Self::PageDown
+                | Self::BackTab
+                | Self::Delete
+                | Self::Insert
+                | Self::Esc
+                | Self::CtrlA
+                | Self::CtrlB
+                | Self::CtrlC
+                | Self::CtrlD
+                | Self::CtrlE
+                | Self::CtrlF
+                | Self::CtrlG
+                | Self::CtrlH
+                | Self::CtrlI
+                | Self::CtrlJ
+                | Self::CtrlK
+                | Self::CtrlL
+                | Self::CtrlM
+                | Self::CtrlN
+                | Self::CtrlO
+                | Self::CtrlP
+                | Self::CtrlQ
+                | Self::CtrlR
+                | Self::CtrlS
+                | Self::CtrlT
+                | Self::CtrlU
+                | Self::CtrlV
+                | Self::CtrlW
+                | Self::CtrlX
+                | Self::CtrlY
+                | Self::CtrlZ
+                | Self::CtrlBackspace
+                | Self::CtrlLeft
+                | Self::CtrlRight
+                | Self::CtrlUp
+                | Self::CtrlDown
+                | Self::CtrlHome
+                | Self::CtrlEnd
+                | Self::CtrlPageUp
+                | Self::CtrlPageDown
+                | Self::CtrlBackTab
+                | Self::CtrlDelete
+                | Self::CtrlInsert
+                | Self::CtrlEnter
+                | Self::CtrlSpace
+                | Self::CtrlTab
+                | Self::CtrlEsc
+                | Self::AltA
+                | Self::AltB
+                | Self::AltC
+                | Self::AltD
+                | Self::AltE
+                | Self::AltF
+                | Self::AltG
+                | Self::AltH
+                | Self::AltI
+                | Self::AltJ
+                | Self::AltK
+                | Self::AltL
+                | Self::AltM
+                | Self::AltN
+                | Self::AltO
+                | Self::AltP
+                | Self::AltQ
+                | Self::AltR
+                | Self::AltS
+                | Self::AltT
+                | Self::AltU
+                | Self::AltV
+                | Self::AltW
+                | Self::AltX
+                | Self::AltY
+                | Self::AltZ
+        )
+    }
+
+    pub fn to_char(&self) -> Option<char> {
         match self {
             Self::Num0 => Some('0'),
             Self::Num1 => Some('1'),
@@ -569,3 +739,40 @@ impl PartialOrd for Key {
         Some(self.cmp(other))
     }
 }
+
+#[derive(Debug, Clone, Copy, PartialEq, Eq, Hash, Serialize, Deserialize)]
+pub enum InputOperation {
+    SetCursor(usize),
+    InsertCharacter(char),
+    GoToPreviousCharacter,
+    GoToNextCharacter,
+    GoToPreviousWord,
+    GoToNextWord,
+    GoToStart,
+    GoToEnd,
+    DeletePreviousCharacter,
+    DeleteNextCharacter,
+    DeletePreviousWord,
+    DeleteNextWord,
+    DeleteLine,
+}
+
+impl Into<InputRequest> for InputOperation {
+    fn into(self) -> InputRequest {
+        match self {
+            Self::SetCursor(i) => InputRequest::SetCursor(i),
+            Self::InsertCharacter(c) => InputRequest::InsertChar(c),
+            Self::GoToPreviousCharacter => InputRequest::GoToPrevChar,
+            Self::GoToNextCharacter => InputRequest::GoToNextChar,
+            Self::GoToPreviousWord => InputRequest::GoToPrevWord,
+            Self::GoToNextWord => InputRequest::GoToNextWord,
+            Self::GoToStart => InputRequest::GoToStart,
+            Self::GoToEnd => InputRequest::GoToEnd,
+            Self::DeletePreviousCharacter => InputRequest::DeletePrevChar,
+            Self::DeleteNextCharacter => InputRequest::DeleteNextChar,
+            Self::DeletePreviousWord => InputRequest::DeletePrevWord,
+            Self::DeleteNextWord => InputRequest::DeleteNextWord,
+            Self::DeleteLine => InputRequest::DeleteLine,
+        }
+    }
+}
